@@ -1,15 +1,6 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
-from spacy.lang.sr import Serbian
 import pytest
 
 
-@pytest.fixture(scope="session")
-def sr_nlp():
-    return Serbian()
-
-
 @pytest.mark.parametrize(
     "string,lemma",
     [
